Alert class

Constructors

Alert()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showError(String? message, {int duration = 5}) → void
showSuccess(String? message, {int duration = 2}) → void
showToast(String message, IconData icon, Color color, {int duration = 2}) → void
showWarning(String? message, {int duration = 2}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance Alert
no setter