BaseState<S extends StatefulWidget, T extends BaseBloc, D> class abstract

Inheritance
Available extensions

Constructors

BaseState()

Properties

baseContext ↔ BuildContext
getter/setter pair
colorScheme → ColorScheme
no setter
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isDarkMode → bool
no setter
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenContext ↔ BuildContext
getter/setter pair
screenHeight ↔ double
getter/setter pair
screenWidth ↔ double
getter/setter pair
theme → ThemeData
no setter
widget → S
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
bloc() → T
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
buildWidget(BuildContext context, RenderDataState<D> state) → Widget
closeKeyboard(BuildContext context) → void

Available on State<StatefulWidget>, provided by the Loading extension

deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant S oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
emit(BaseEvent event) → dynamic
getLoadingStatus() → bool

Available on State<StatefulWidget>, provided by the Loading extension

hideKeyboard() → void
hideLoading() → void

Available on State<StatefulWidget>, provided by the Loading extension

initState() → void
Called when this object is inserted into the tree.
inherited
listenToState(BuildContext context, BaseStates state) → void
locale() → String

Available on State<StatefulWidget>, provided by the Loading extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
showError(String message) → void

Available on State<StatefulWidget>, provided by the Alerts extension

showLoading({BuildContext? context, bool showProgress = false, Duration? duration, bool canCancelLoading = false}) → void

Available on State<StatefulWidget>, provided by the Loading extension

showSuccess(String message) → void

Available on State<StatefulWidget>, provided by the Alerts extension

showWarning(String message) → void

Available on State<StatefulWidget>, provided by the Alerts extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited