NonRenderState class
- Inheritance
-
- Object
- BaseStates
- NonRenderState
- Implementers
- AddCardError
- AddCardInvalidEmail
- AddCardInvalidMobile
- AddCardProceedToHostPayment
- AddCardRedirectReady
- CloseSheetNonRenderState
- EndLoadingNonRenderState
- ErrorState
- LoadingNonRenderState
- OpenAddCardFormState
- PaymentOptionsApplePayPaymentFailed
- PaymentOptionsApplePayPaymentSucceeded
- PaymentOptionsGooglePayPaymentFailed
- PaymentOptionsGooglePayPaymentSucceeded
- ShowPaymentOptionsSheetNonRenderState
- SubmittingOrderFlowAwaiting3ds
- SubmittingOrderFlowAwaitingCvv
- SubmittingOrderFlowFailure
- SubmittingOrderFlowSuccess
- SuccessMessageState
- TabbyCheckoutConfirmFailed
- TabbyCheckoutConfirmSucceeded
- TabbyCheckoutInitFailed
- TabbyCheckoutInitSucceeded
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited