data/constants/payorc_cancellation library
Classes
- PayorcCancellation
- Canonical payload delivered to host callbacks when a PayOrc payment flow is cancelled by the user (closing a 3DS WebView, dismissing a native pay sheet, closing the Tabby checkout, etc.).