AddCardOrderDetails class

Constructors

AddCardOrderDetails({required String mOrderId, required String currency, required String description, required String amount})

Properties

amount → String
final
currency → String
final
description → String
final
hashCode → int
The hash code for this object.
no setterinherited
mOrderId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited