AddCardResponse class

Constructors

AddCardResponse({required AddCardResponseData data, required String message, required String status, required String code})
AddCardResponse.fromJson(Map<String, dynamic> json)
factory

Properties

code → String
final
data → AddCardResponseData
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited