CardData class

Data collected from the Add Card form (new card entry or edit), or a saved card row.

Constructors

CardData({String? cardNumber, required String cardholderName, required String expiryMonth, required String expiryYear, required String cvv, String? email, String? countryCode, String? mobile, String? cardNetwork, String? cardId, String? paymentToken, String? brand, String? displayLastFour, Map<String, dynamic>? rawResponse})
const
CardData.fromJson(Map<String, dynamic> json)
factory
CardData.fromSDK(Map<String, dynamic> json)
factory

Properties

brand → String?
final
cardholderName → String
final
cardId → String?
final
cardNetwork → String?
final
cardNumber → String?
Full card number. Null when editing (card number is not re-entered).
final
countryCode → String?
final
cvv → String
final
displayLastFour → String?
final
email → String?
final
expiryMonth → String
final
expiryYear → String
final
hashCode → int
The hash code for this object.
no setterinherited
lastFourDigits → String
Last four digits for UI and OTP flows.
no setter
maskedNumber → String
no setter
mobile → String?
final
paymentToken → String?
final
rawResponse → Map<String, dynamic>?
final
resolvedBrand → String
Brand string for CardBrandImage (non-null fallback).
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? cardNumber, String? cardholderName, String? expiryMonth, String? expiryYear, String? cvv, String? email, String? countryCode, String? mobile, String? cardId, String? paymentToken, String? brand, String? displayLastFour, Map<String, dynamic>? rawResponse}) → CardData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
withoutSensitiveData() → CardData
Returns a copy of this card data with sensitive info (CVV) cleared.

Operators

operator ==(Object other) → bool
The equality operator.
inherited