withoutSensitiveData method
Returns a copy of this card data with sensitive info (CVV) cleared.
Implementation
CardData withoutSensitiveData() => copyWith(cvv: '');
Returns a copy of this card data with sensitive info (CVV) cleared.
CardData withoutSensitiveData() => copyWith(cvv: '');