CheckoutCustomizationResponse class

Response from POST .../sdk/checkout/customization.

Constructors

CheckoutCustomizationResponse({CheckoutCustomizationData? data, String? message, String? status, String? code})
const
CheckoutCustomizationResponse.fromJson(Map<String, dynamic> json)
factory

Properties

code → String?
final
data → CheckoutCustomizationData?
final
hashCode → int
The hash code for this object.
no setterinherited
isSuccess → bool
no setter
message → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited