CompanyDetails class
Constructors
- CompanyDetails({String? favIcon, String? logo, String? letterHead, String? title, String? termsAndCondition})
-
const
-
CompanyDetails.fromJson(Map<
String, dynamic> json) -
factory
Properties
- favIcon → String?
-
final
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- letterHead → String?
-
final
- logo → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- termsAndCondition → String?
-
final
- title → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited