MerchantDetails class
Constructors
-
MerchantDetails({String? theme, String? icon, String? logo, int? useLogo, String? weAcceptImage, String? brandColor, String? buttonColor, String? accentColor, String? brandingLanguage, String? fontName, int? amountVisible, int? shippingAddressVisible, int? locationVisible, int? mobileVisible, int? cobrandingLogoVisible, String? cobrandingLogoFilename, int? convenienceVisible, int? shippingFeeVisible, int? emailVisible, int? nameVisible, int? remarkVisible, String? remarkLabel, String? fieldBorder, String? borderColor, String? appStyle, String? textPrimary, String? textSecondary, int? autoselectColor, Map<
String, dynamic> ? sdkOptions, String? cobrandingLogo, String? merchantName, String? companyName, String? tcLink, int? useLogoInsteadIcon, int? shippingVisible, List<String> supportedCardSchemes = const []}) -
const
-
MerchantDetails.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accentColor → String?
-
final
- amountVisible → int?
-
final
- appStyle → String?
-
final
- autoselectColor → int?
-
final
- borderColor → String?
-
final
- brandColor → String?
-
final
- brandingLanguage → String?
-
final
-
final
- cobrandingLogo → String?
-
final
- cobrandingLogoFilename → String?
-
final
- cobrandingLogoVisible → int?
-
final
- companyName → String?
-
final
- convenienceVisible → int?
-
final
- emailVisible → int?
-
final
- fieldBorder → String?
-
final
- fontName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
final
- locationVisible → int?
-
final
- logo → String?
-
final
- merchantName → String?
-
final
- mobileVisible → int?
-
final
- nameVisible → int?
-
final
- remarkLabel → String?
-
final
- remarkVisible → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sdkOptions
→ Map<
String, dynamic> ? -
final
- shippingAddressVisible → int?
-
final
- shippingFeeVisible → int?
-
final
- shippingVisible → int?
-
final
-
supportedCardSchemes
→ List<
String> -
final
- tcLink → String?
-
final
- textPrimary → String?
-
final
- textSecondary → String?
-
final
- theme → String?
-
final
- useLogo → int?
-
final
- useLogoInsteadIcon → int?
-
final
- weAcceptImage → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited