CustomerCardsResponse class
One saved card row from POST .../sdk/customer/cards.
Constructors
-
CustomerCardsResponse({required List<
CardData> data, required String message, required String status, required String code}) -
CustomerCardsResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited