OrderSummary class

Order calculation summary for the review order screen.

Constructors

OrderSummary({required String subtotal, required String shipping, required String tax, required String total, required String currency})
const

Properties

currency → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shipping → String
final
subtotal → String
final
tax → String
final
total → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited