PaymentGatewayParams class
Parameters passed to the app when building the payment gateway screen
(full-screen mode). Use when providing PayorcSdk.showPayment with
paymentGatewayScreen.
Constructors
-
PaymentGatewayParams({required PaymentRequest request, PaymentRequest? addCardRequest, String? logoPath, void onCardSelected(CardData card)?, OrderSummary? orderSummary, List<
BillingAddressOption> billingAddresses = const [], String? selectedBillingAddressId, void onBillingAddressSelected(String addressId)?, VoidCallback? onAddNewAddress, void onDeleteAddress(String addressId)?, VoidCallback? onProceedToPayment, void onAddNewCard(CardData card)?}) -
const
Properties
- addCardPaymentRequest → PaymentRequest
-
Resolved request for AddCardForm / add-card APIs.
no setter
- addCardRequest → PaymentRequest?
-
PayOrc
/sdk/add-cardpayload. When omitted, derived from request when it is a submit-order request.final -
billingAddresses
→ List<
BillingAddressOption> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logoPath → String?
-
final
- onAddNewAddress → VoidCallback?
-
final
- onAddNewCard → void Function(CardData card)?
-
Called when user adds a new card (Pay with Card). Same as
showOptionsSheet.final - onBillingAddressSelected → void Function(String addressId)?
-
final
- onCardSelected → void Function(CardData card)?
-
final
- onDeleteAddress → void Function(String addressId)?
-
final
- onProceedToPayment → VoidCallback?
-
final
- orderSummary → OrderSummary?
-
final
- request → PaymentRequest
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedBillingAddressId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited