SdkPaymentServiceAddress class

Billing or shipping block from payment API (address_line_1 or address_line1).

Constructors

SdkPaymentServiceAddress({String? addressLine1, String? addressLine2, String? city, String? state, String? country, String? pincode})
SdkPaymentServiceAddress.fromJson(Map<String, dynamic> json)
factory

Properties

addressLine1 → String?
final
addressLine2 → String?
final
city → String?
final
country → String?
final
hashCode → int
The hash code for this object.
no setterinherited
pincode → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited