TabbyInitData class

data object from Tabby init (credentials for TabbySDK.setup).

Constructors

TabbyInitData({int? orderId, String? mode, String? merchantCode, String? password, String? extraKey})
const
TabbyInitData.fromJson(Map<String, dynamic> json)
factory

Properties

extraKey → String?
final
hashCode → int
The hash code for this object.
no setterinherited
merchantCode → String?
final
mode → String?
final
orderId → int?
final
password → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited