TabbyInitResponse class

Response from POST .../sdk/tabby/init.

Constructors

TabbyInitResponse({TabbyInitData? data, String? message, String? status, String? code})
const
TabbyInitResponse.fromJson(Map<String, dynamic> json)
factory

Properties

code String?
final
data TabbyInitData?
final
hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
no setter
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited