Token class

Constructors

Token({required String data, required String signature, Header? header, required String version, String? protocolVersion, Map<String, dynamic>? intermediateSigningKey, String? signedMessage})
Token.fromJson(Map<String, dynamic> json)
factory

Properties

data → String
final
hashCode → int
The hash code for this object.
no setterinherited
final
intermediateSigningKey → Map<String, dynamic>?
final
protocolVersion → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signature → String
final
signedMessage → String?
final
version → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited