SdkLoading class

Constructors

SdkLoading()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

cancelFunc ↔ CancelFunc?
getter/setter pair
isVisible → bool
no setter
loaderVisible ↔ bool
getter/setter pair

Static Methods

hide() → void
show({BuildContext? context, bool showProgress = false, Duration? duration, bool canCancelLoading = false}) → void