SdkLocaleKeys class abstract final

Localize string keys using the SDK internal translation tables.

This is a minimal replacement for the merchant_app string extension. English message keys shipped with the SDK; pass to StringTranslate.localize.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

noInternetConnection → const String