BaseModel class

Minimal BaseModel implementation used by the copied lib/bases/base_bloc.dart.

The original merchant_app model includes many fields. For compilation inside this SDK, we only keep what BaseBloc reads:

  • isSuccess
  • message
Implementers

Constructors

BaseModel({required bool isSuccess, String? message})
const
BaseModel.fromJson(dynamic json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isSuccess → bool
final
message → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

exception() → BaseModel
Placeholder exception model.