PayOrc class
Host-facing PayOrc helpers (add card, submit-order flow, etc.).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
addNewCard(
BuildContext context, {required PaymentRequest paymentRequest, required void onAddCard(BuildContext sheetContext, CardData card), void onCancel(BuildContext sheetContext)?, CardData? initialCard, bool savedCardEditMode = false, String? recoveryErrorCode, String? recoveryErrorMessage}) → Future< void> - Opens the add-card modal bottom sheet (AddCardForm) with SDK theme.
-
applePay(
{required PaymentRequest paymentRequest, required void onApplePayResult(Map< String, dynamic> onApplePayResult), void onApplePayError(Object error)?}) → Future<void> - Triggers a headless Google Pay payment using the PayOrc SDK.
-
googlePay(
{required PaymentRequest paymentRequest, required void onGooglePayResult(Map< String, dynamic> onApplePayResult), void onGooglePayError(Object error)?}) → Future<void> -
submitOrder(
BuildContext context, {required CardData card, required PaymentRequest paymentRequest, required PaymentRequest addCardPaymentRequest, required void onNewCardAdded(CardData input), void onSuccessPayment(BuildContext submittingContext, Map< String, dynamic> merchantResponse)?, BuildContext? mountedCheckContext, void onPaymentFailed(BuildContext submitModalContext, String message, {String? code})?, VoidCallback? onRetryPayment}) → Future<void> - Opens the non-dismissible submit-order (card payment) modal bottom sheet.
-
tabby(
{required BuildContext context, required PaymentRequest paymentRequest, required void onTabbyAuthorized(BuildContext launchingContext, Map< String, dynamic> merchantResponse), void onTabbyError(Object? error)?}) → Future<void> - Triggers the Tabby checkout flow directly, without requiring an embedded widget.