AddCardForm class

SDK wrapper that injects AddCardFormBloc into AddCardFormScene.

Copy for the sheet (titles, subtitles, labels, hints, primary button) uses SDK defaults unless you set PayorcSdk.customization(addCardForm: …) globally (see PayorcSdkAddCardFormCustomization).

Inheritance
Available extensions

Constructors

AddCardForm({Key? key, required PaymentRequest paymentRequest, required void onAddCard(CardData card), required VoidCallback onCancel, void onAddCardError(Object? error)?, CardData? initialCard, bool savedCardEditMode = false, String? recoveryErrorCode, String? recoveryErrorMessage})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
initialCard → CardData?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onAddCard → void Function(CardData card)
final
onAddCardError → void Function(Object? error)?
Called for both 3DS cancellation and other add-card failures.
final
onCancel → VoidCallback
final
paymentRequest → PaymentRequest
final
recoveryErrorCode → String?
final
recoveryErrorMessage → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
savedCardEditMode → bool
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
locale(BuildContext context) → String

Available on Widget, provided by the WidgetExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited