AppTextField class

Inheritance
Available extensions

Constructors

AppTextField({String? hint, double? hintSize, String label = "", String? title, TextInputType keyboardType = TextInputType.text, FormFieldValidator<String>? validator, dynamic onChanged(String)?, dynamic onSubmit(String)?, bool obscureText = false, TextEditingController? controller, bool readOnly = false, GestureTapCallback? onTap, Widget? icon, int? maxLength, String? initValue, bool enable = true, String? image, double? imageSize = 24, Widget? endSuffix, bool enableEdit = false, Widget? endIcon, String? suffix, GestureTapCallback? onSuffixTap, int maxLines = 1, bool showCounter = false, List<TextInputFormatter>? formatter, FocusNode? focusNode, Color? iconColor, Color fillColor = AppColors.transparent, Color? hintColor, Color? labelColor, double radius = _AppTextFieldTheme.small, bool enableInteractiveSelection = true, bool showBorder = true, double? height, TextAlign textAlign = TextAlign.start, TextDirection? textDirection, bool autofocus = false, Key? key})

Properties

autofocus → bool
final
controller → TextEditingController?
final
enable → bool
final
enableEdit → bool
final
enableInteractiveSelection → bool
final
endIcon → Widget?
final
endSuffix → Widget?
final
fillColor → Color
final
focusNode → FocusNode?
final
formatter → List<TextInputFormatter>?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
hint → String?
final
hintColor → Color?
When null, uses AppColors.dem (same default as before host hint APIs).
final
hintSize → double?
final
icon → Widget?
final
iconColor → Color?
final
image → String?
final
imageSize → double?
final
initValue → String?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType
final
label → String
final
labelColor → Color?
final
maxLength → int?
final
maxLines → int
final
obscureText → bool
final
onChanged → dynamic Function(String)?
final
onSubmit → dynamic Function(String)?
final
onSuffixTap → GestureTapCallback?
final
onTap → GestureTapCallback?
final
radius → double
final
readOnly → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showBorder → bool
final
showCounter → bool
final
suffix → String?
final
textAlign → TextAlign
final
textDirection → TextDirection?
final
title → String?
final
validator → FormFieldValidator<String>?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<AppTextField>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
locale(BuildContext context) → String

Available on Widget, provided by the WidgetExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited