LoaderButton class

Inheritance
Available extensions

Constructors

LoaderButton({Key? key, String title = "", Color? backgroundColor, Color? textColor, double fontSize = 16, FontWeight fontWeight = FontWeight.w500, double radius = 12, double minWidth = double.infinity, double height = 48, VoidCallback? onPressed, Widget? icon, IconData? fontAwesomeIcon, double iconSize = 20, Color borderColor = AppColors.transparent, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.center, bool horizontalGradient = true, bool gradient = false, bool shadow = false, bool isLoading = false, Widget? loadingIndicator})
const

Properties

backgroundColor → Color?
final
borderColor → Color
final
fontAwesomeIcon → IconData?
final
fontSize → double
final
fontWeight → FontWeight
final
gradient → bool
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
horizontalGradient → bool
final
icon → Widget?
final
iconSize → double
final
isLoading → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingIndicator → Widget?
final
mainAxisAlignment → MainAxisAlignment
final
minWidth → double
final
onPressed → VoidCallback?
final
radius → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadow → bool
final
textColor → Color?
When null, uses PayorcSdkUiConstants.buttonForegroundColorOrDefault.
final
title → String
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<LoaderButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
locale(BuildContext context) → String

Available on Widget, provided by the WidgetExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited