onError property
Called when the native pay sheet is cancelled by the user (payload:
{'status': 'failed', 'code': 'USER_CANCELLED', ...}) or fails.
Implementation
final void Function(Object? error)? onError;
Called when the native pay sheet is cancelled by the user (payload:
{'status': 'failed', 'code': 'USER_CANCELLED', ...}) or fails.
final void Function(Object? error)? onError;