onTapOutside property
A callback to be invoked when a tap is detected outside of this TapRegion
The PointerDownEvent passed to the function is the event that caused the
notification. If this region is part of a group
then it's possible that the event may be outside of this immediate region,
although it will be within the region of one of the group members.
This is useful if you want to un-focus the Pinput when user taps outside of it
Implementation
final TapRegionCallback? onTapOutside;