showErrorWhenFocused property
If true, the error will also be displayed in the focused state. Otherwise the error is not displayed in the focused state.
Implementation
final bool showErrorWhenFocused;
If true, the error will also be displayed in the focused state. Otherwise the error is not displayed in the focused state.
final bool showErrorWhenFocused;