PaymentOptionsSelectMethod class

Updates the highlighted payment method tile (Apple / Google / Tabby / …).

Inheritance

Constructors

PaymentOptionsSelectMethod(String? option)

Properties

hashCode → int
The hash code for this object.
no setterinherited
option → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited