PaymentOptionsSheet class

Host-facing widget: provides PaymentOptionsBloc and PaymentOptionsScene.

Inheritance
Available extensions

Constructors

PaymentOptionsSheet({Key? key, String errorCode = 'TXN_DECLINED', String? errorMessage, VoidCallback? onRetry, VoidCallback? onApplePay, VoidCallback? onGooglePay, VoidCallback? onSamsungPay, VoidCallback? onTabby, VoidCallback? onBack, bool askForCVV = false, void onCvvSubmitted(String cvv)?, required void onAddNewCard(CardData input), PaymentRequest? paymentRequest, PaymentRequest? addCardRequest, void onApplePayWalletResult(WalletPaymentResult result)?, void onApplePayPaymentResponse(PaymentResponse response)?, void onApplePayResult(Map<String, dynamic> result)?, void onGooglePayResult(Map<String, dynamic> result)?, void onPaymentError(Object? error)?, VoidCallback? onConfirm})
const

Properties

addCardRequest PaymentRequest?
final
askForCVV bool
final
errorCode String
final
errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onAddNewCard → void Function(CardData input)
final
onApplePay VoidCallback?
final
onApplePayPaymentResponse → void Function(PaymentResponse response)?
final
onApplePayResult → void Function(Map<String, dynamic> result)?
final
onApplePayWalletResult → void Function(WalletPaymentResult result)?
final
onBack VoidCallback?
final
onConfirm VoidCallback?
final
onCvvSubmitted → void Function(String cvv)?
final
onGooglePay VoidCallback?
final
onGooglePayResult → void Function(Map<String, dynamic> result)?
final
onPaymentError → void Function(Object? error)?
final
onRetry VoidCallback?
final
onSamsungPay VoidCallback?
final
onTabby VoidCallback?
final
paymentRequest PaymentRequest?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
locale(BuildContext context) String

Available on Widget, provided by the WidgetExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited