onComplete property

void Function(BuildContext submittingContext, Map<String, dynamic> merchantResponse) onComplete
final

Called with sheetHostContext when /sdk/payment succeeds — right after the submitting sheet is popped and the host context is still mounted, before the optional PaymentConfirmedSheet is shown.

Implementation

final void Function(BuildContext submittingContext, Map<String, dynamic> merchantResponse) onComplete;