sheetHostContext property
Context that stays valid after dismissing this sheet — used for PaymentConfirmedSheet and onComplete (normally the caller's context).
Implementation
final BuildContext sheetHostContext;
Context that stays valid after dismissing this sheet — used for PaymentConfirmedSheet and onComplete (normally the caller's context).
final BuildContext sheetHostContext;