ui/submitting_order_sheet library
Classes
- SubmittingOrderSheet
- Bottom sheet shown while an order is being submitted. Shows a circular progress indicator, progress bar, selected card summary, and a warning not to leave the page. If progress is null, progress animates from 0 to 100 over duration.