CheckoutPaymentMethodKind enum

Parsed row kind for payment pickers (options sheet, failed-payment retry, etc.).

Inheritance
Available extensions

Values

applePay → const CheckoutPaymentMethodKind
googlePay → const CheckoutPaymentMethodKind
tabby → const CheckoutPaymentMethodKind
samsungPay → const CheckoutPaymentMethodKind
newCard → const CheckoutPaymentMethodKind
storedCard → const CheckoutPaymentMethodKind
clickToPay → const CheckoutPaymentMethodKind
unknown → const CheckoutPaymentMethodKind

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CheckoutPaymentMethodKind>
A constant List of the values in this enum, in order of their declaration.