NetworkProvider class

Constructors

NetworkProvider()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addHeaders(Map<String, dynamic> headers) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request(String url, {HTTPMethod method = HTTPMethod.get, Map<String, dynamic>? params, Map<String, dynamic>? body, String? bodyString, Map<String, dynamic>? headers, bool showProgress = false, bool isFormData = false, CancelToken? cancelToken, ResponseType? responseType, bool includeNon2xxBody = false}) Future
toString() String
A string representation of this object.
inherited
updateHeaders(Map<String, dynamic> headers) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited