AddCardBillingDetails class

Constructors

AddCardBillingDetails({required String addressLine1, required String addressLine2, required String city, required String province, required String country, required String pin})

Properties

addressLine1 String
final
addressLine2 String
final
city String
final
country String
final
hashCode int
The hash code for this object.
no setterinherited
pin String
final
province String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited