AddCardCardDetails class

Constructors

AddCardCardDetails({String? paymentToken, required String cardHolderName, required String cardNumber, required String cvv, required String expiry})

Properties

cardHolderName String
final
cardNumber String
final
cvv String
final
expiry String
final
hashCode int
The hash code for this object.
no setterinherited
paymentToken String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited