AddCardRequestData class
Constructors
-
AddCardRequestData({required String action, required String requestClass, required String captureMethod, required String type, required AddCardCustomerDetails customerDetails, required AddCardBillingDetails billingDetails, required AddCardOrderDetails orderDetails, required AddCardCardDetails cardDetails, required AddCardShippingDetails shippingDetails, required List parameters, required List<
Map< customData, Map<String, dynamic> >String, dynamic> ? urls})
Properties
- action → String
-
final
- billingDetails → AddCardBillingDetails
-
final
- captureMethod → String
-
final
- cardDetails → AddCardCardDetails
-
final
-
customData
→ List<
Map< String, dynamic> > -
final
- customerDetails → AddCardCustomerDetails
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- orderDetails → AddCardOrderDetails
-
final
- parameters → List
-
final
- requestClass → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shippingDetails → AddCardShippingDetails
-
final
- type → String
-
final
-
urls
→ Map<
String, dynamic> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited