AddCardResponseData class

Constructors

AddCardResponseData({required String mOrderId, required String pOrderId, required String status, required String amount, required String currency, required String redirectUrl, String? reason})
AddCardResponseData.fromJson(Map<String, dynamic> json)
factory

Properties

amount String
final
currency String
final
hashCode int
The hash code for this object.
no setterinherited
mOrderId String
final
pOrderId String
final
reason String?
final
redirectUrl String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited