BillingAddressOption class
A selectable billing address (e.g. Home, Office) for review order.
Constructors
Properties
- addressLine1 → String
-
final
- addressLine2 → String?
-
final
- city → String
-
final
- country → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- label → String
-
final
- name → String
-
final
- phone → String?
-
final
- pin → String
-
final
- province → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited