AvailablePaymentMethod class
Constructors
-
AvailablePaymentMethod({required String type, int sequence = 0, int show = 0, List<
String> schemes = const [], String psp = '', String identifier = '', String merchantId = '', String gatewayMerchantId = '', String publicKey = '', String merchantCode = ''}) -
const
-
AvailablePaymentMethod.fromJson(Map<
String, dynamic> json) -
factory
Properties
- gatewayMerchantId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
final
- merchantCode → String
-
final
- merchantId → String
-
final
- psp → String
-
final
- publicKey → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
schemes
→ List<
String> -
final
- sequence → int
-
final
- show → int
-
final
- type → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited