CheckoutCustomizationData class
Constructors
-
CheckoutCustomizationData({List<
AvailablePaymentMethod> availableMethods = const [], String? payorcLogo, MerchantDetails? merchantDetails, bool? showNewCardBillingSection, CompanyDetails? companyDetails}) -
const
-
CheckoutCustomizationData.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
availableMethods
→ List<
AvailablePaymentMethod> -
final
- companyDetails → CompanyDetails?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- merchantDetails → MerchantDetails?
-
final
- payorcLogo → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showNewCardBillingSection → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited