OrderDetails class
Order details for the payment.
Constructors
- OrderDetails({String mOrderId = "", required String amount, String convenienceFee = '', String quantity = '', required String currency, String description = ''})
-
const
- OrderDetails.forAddCard({String mOrderId = "", required String currency, String description = '', required String amount})
-
Add-card / verification:
amount, convenienceFee, and quantity are unused in API JSON.const
Properties
- amount → String
-
final
- convenienceFee → String
-
final
- currency → String
-
final
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mOrderId → String
-
final
- quantity → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited