SdkPaymentMethodDataSlice class
Constructors
- SdkPaymentMethodDataSlice({String? scheme, String? cardCountry, String? cardType, String? maskCardNumber})
-
SdkPaymentMethodDataSlice.fromJson(Map<
String, dynamic> json) -
factory
Properties
- cardCountry → String?
-
final
- cardType → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maskCardNumber → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheme → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited