SdkPaymentTransactionData class
Typed data object from POST .../sdk/payment (success, failure, 3DS, etc.).
Constructors
-
SdkPaymentTransactionData({required Map<
String, dynamic> raw, String? action, String? status, String? orderStatus, String? mOrderId, String? pOrderId, String? pRequestId, String? pspRefId, String? transactionId, bool? isLive, String? terminalLabel, String? remark, String? reason, String? currency, String? amount, String? channel, String? channelId, String? shippingFee, String? convenienceFee, SdkPaymentCustomerSnapshot? customerDetails, SdkPaymentServiceAddress? billingAddress, SdkPaymentServiceAddress? shippingAddress, String? ipCountry, String? psp, String? paymentMethod, String? mPaymentToken, String? transactionTime, SdkPaymentMethodDataSlice? paymentMethodData, String? apmName, String? apmIdentifier, String? subMerchantIdentifier, List<SdkPaymentSlotEntry> parameters = const [], List<SdkPaymentSlotEntry> customData = const [], bool? fraud, String? type, String? redirectUrl}) -
SdkPaymentTransactionData.fromJson(Map<
String, dynamic> json) -
factory
Properties
- action → String?
-
final
- amount → String?
-
final
- apmIdentifier → String?
-
final
- apmName → String?
-
final
- billingAddress → SdkPaymentServiceAddress?
-
final
- channel → String?
-
final
- channelId → String?
-
final
- convenienceFee → String?
-
final
- currency → String?
-
final
-
customData
→ List<
SdkPaymentSlotEntry> -
final
- customerDetails → SdkPaymentCustomerSnapshot?
-
final
- fraud → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ipCountry → String?
-
final
- isLive → bool?
-
final
- mOrderId → String?
-
final
- mPaymentToken → String?
-
final
- orderStatus → String?
-
final
-
parameters
→ List<
SdkPaymentSlotEntry> -
final
- paymentMethod → String?
-
final
- paymentMethodData → SdkPaymentMethodDataSlice?
-
final
- pOrderId → String?
-
final
- pRequestId → String?
-
final
- psp → String?
-
final
- pspRefId → String?
-
final
-
raw
→ Map<
String, dynamic> -
final
- reason → String?
-
final
- redirectUrl → String?
-
final
- remark → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shippingAddress → SdkPaymentServiceAddress?
-
final
- shippingFee → String?
-
final
- status → String?
-
final
- subMerchantIdentifier → String?
-
final
- terminalLabel → String?
-
final
- transactionId → String?
-
final
- transactionTime → String?
-
final
- type → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
tryParse(
Map< String, dynamic> data) → SdkPaymentTransactionData? -
tryParseDynamic(
dynamic value) → SdkPaymentTransactionData? -
Parses API
datawhen it is a JSON object; returnsnullfor arrays, primitives, or missing.