RoutePath class
Route names used by the copied lib/bases/base_bloc.dart.
These are placeholders to keep the SDK compileable; host apps should
register matching routes if they use BaseBloc.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- login → const String
- noInternet → const String