PayMethodTile class
Reusable tile for a payment method option (e.g. Apple Pay, Google Pay, Add New Card). Shows an optional icon or image, title, and trailing arrow.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- PayMethodTile
- Available extensions
Constructors
- PayMethodTile({Key? key, required VoidCallback? onTap, required Color backgroundColor, IconData? icon, String? image, double? imageHeight, double? imageWidth, Color? iconColor, required String title, Widget? trailing, bool isSelected = false, Color? selectedBackgroundColor, Color? selectedBorderColor, Color? titleColor, double? height, double? borderRadius, bool useHostBackground = false})
Properties
- backgroundColor → Color
-
final
- borderRadius → double?
-
Corner radius for the tile surface (default 12).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
When set, fixes the tile height (content is vertically centered).
final
- icon → IconData?
-
final
- iconColor → Color?
-
When null, icon color matches title contrast on backgroundColor.
final
- image → String?
-
final
- imageHeight → double?
-
final
- imageWidth → double?
-
final
- isSelected → bool
-
When true, uses selectedBackgroundColor and selectedBorderColor.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onTap → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedBackgroundColor → Color?
-
Background color when isSelected is true. Defaults to AppColors.lighblue.
final
- selectedBorderColor → Color?
-
Border color when isSelected is true. Defaults to AppColors.primary.
final
- title → String
-
final
- titleColor → Color?
-
When set, used for the title (and icon when iconColor is null).
final
- trailing → Widget?
-
final
- useHostBackground → bool
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
locale(
BuildContext context) → String -
Available on Widget, provided by the WidgetExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited