PinInput class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- PinInput
- Available extensions
Constructors
-
PinInput({Key? key, int fieldsCount = 6, double width = 39, double height = 39, TextInputType keyboardType = TextInputType.number, FocusNode? focusNode, TextEditingController? controller, ValueChanged<
String> ? onSubmit, ValueChanged<String> ? onChanged, PinTheme? pinTheme, PinTheme? focusedPinTheme, PinTheme? submittedPinTheme, String? validator(String?)?}) -
const
Properties
- animationCurve → Curve
-
curve of every
PinputAnimationfinalinherited - animationDuration → Duration
-
Duration of every
PinputAnimationfinalinherited -
autofillHints
→ Iterable<
String> ? -
See EditableText.autofillHints
finalinherited
- autofocus → bool
-
See EditableText.autofocus
finalinherited
- closeKeyboardWhenCompleted → bool
-
If true keyboard will be closed
finalinherited
- contextMenuBuilder → EditableTextContextMenuBuilder?
-
Builds the text selection toolbar when requested by the user.
finalinherited
- controller → TextEditingController?
-
Used to get, modify PinPut value and more.
Don't forget to dispose controller
finalinherited
- crossAxisAlignment → CrossAxisAlignment
-
Defines how
Pinputand (errorTextorerrorBuilder) are being placed inside Columnfinalinherited - cursor → Widget?
-
If
showCursortrue the focused field will show passed Widgetfinalinherited - defaultPinTheme → PinTheme?
-
Theme of the pin in default state
finalinherited
- disabledPinTheme → PinTheme?
-
Theme of the pin in disabled state
finalinherited
- enabled → bool
-
Defines
Pinputstatefinalinherited - enableIMEPersonalizedLearning → bool
-
Whether to enable that the IME update personalized data such as typing history and user dictionary data.
finalinherited
- enableInteractiveSelection → bool?
-
Whether to enable text selection and interactive features like copy/paste.
When enabled, users can select text, use Ctrl+V to paste, and access context menus.
finalinherited
- enableSuggestions → bool
-
See EditableText.enableSuggestions
finalinherited
- errorBuilder → PinputErrorBuilder?
-
If
Pinputhas error anderrorBuilderis passed it will be rendered under the Pinputfinalinherited - errorPinTheme → PinTheme?
-
Theme of the pin in error state
finalinherited
- errorText → String?
-
Text displayed under the Pinput if Pinput is invalid
finalinherited
- errorTextStyle → TextStyle?
-
Style of error text
finalinherited
- focusedPinTheme → PinTheme?
-
Theme of the pin in focused state
finalinherited
- focusNode → FocusNode?
-
Defines the keyboard focus for this
To give the keyboard focus to this widget, provide a
focusNodeand then use the current FocusScope to request the focus: Don't forget to dispose focusNodefinalinherited - followingPinTheme → PinTheme?
-
Theme of the pin in following state
finalinherited
- forceErrorState → bool
-
If true
errorPinThemewill be applied anderrorTextwill be displayed under the Pinputfinalinherited - hapticFeedbackType → HapticFeedbackType
-
Use haptic feedback everytime user types on keyboard
See more details in HapticFeedback
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputFormatters
→ List<
TextInputFormatter> -
See EditableText.inputFormatters
finalinherited
- isCursorAnimationEnabled → bool
-
Whether to enable cursor animation
finalinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardAppearance → Brightness?
-
The appearance of the keyboard.
This setting is only honored on iOS devices.
If unset, defaults to ThemeData.brightness.
finalinherited
- keyboardType → TextInputType
-
See EditableText.keyboardType
finalinherited
- length → int
-
Displayed fields count. PIN code length.
finalinherited
- mainAxisAlignment → MainAxisAlignment
-
Defines how
Pinputfields are being placed inside Rowfinalinherited - mouseCursor → MouseCursor?
-
See EditableText.mouseCursor
finalinherited
- obscureText → bool
-
Whether hide typed pin or not
finalinherited
- obscuringCharacter → String
-
Provide any symbol to obscure each
Pinputpin Recommended ●finalinherited - obscuringWidget → Widget?
-
IF
obscureTextis true typed text will be replaced with passed Widgetfinalinherited - onAppPrivateCommand → AppPrivateCommandCallback?
-
See EditableText.onAppPrivateCommand
finalinherited
-
onChanged
→ ValueChanged<
String> ? -
Called every time input value changes.
finalinherited
-
onClipboardFound
→ ValueChanged<
String> ? -
Fires when clipboard has text of Pinput's length
finalinherited
-
onCompleted
→ ValueChanged<
String> ? -
Fires when user completes pin input
finalinherited
- onLongPress → VoidCallback?
-
Triggered when a pointer has remained in contact with the Pinput at the
same location for a long period of time.
finalinherited
-
onSubmitted
→ ValueChanged<
String> ? -
See EditableText.onSubmitted
finalinherited
- onTap → VoidCallback?
-
Called when user clicks on PinPut
finalinherited
- onTapOutside → TapRegionCallback?
-
A callback to be invoked when a tap is detected outside of this TapRegion
The PointerDownEvent passed to the function is the event that caused the
notification. If this region is part of a group
then it's possible that the event may be outside of this immediate region,
although it will be within the region of one of the group members.
This is useful if you want to un-focus the
Pinputwhen user taps outside of itfinalinherited - onTapUpOutside → TapRegionUpCallback?
-
Called for each tap up that occurs outside of the TextFieldTapRegion
group when the text field is focused.
finalinherited
- pinAnimationType → PinAnimationType
-
Animation Type of each
Pinputfield options: none, scale, fade, slide, rotationfinalinherited - pinContentAlignment → AlignmentGeometry
-
Defines how each
Pinputfield are being placed within the containerfinalinherited - pinputAutovalidateMode → PinputAutovalidateMode
-
Return null if pin is valid or any String otherwise
finalinherited
- preFilledWidget → Widget?
-
Widget that is displayed before field submitted.
finalinherited
- readOnly → bool
-
See EditableText.readOnly
finalinherited
- restorationId → String?
-
See TextField.restorationId
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollPadding → EdgeInsets
-
When this widget receives focus and is not completely visible (for example scrolled partially
off the screen or overlapped by the keyboard)
then it will attempt to make itself visible by scrolling a surrounding Scrollable, if one is present.
This value controls how far from the edges of a Scrollable the TextField will be positioned after the scroll.
finalinherited
- selectionControls → TextSelectionControls?
-
See EditableText.selectionControls
finalinherited
- separatorBuilder → JustIndexedWidgetBuilder?
-
Builds a
Pinputseparator If null SizedBox(width: 8) will be usedfinalinherited - showCursor → bool
-
Whether show cursor or not
Default cursor '|' or
cursorfinalinherited - showErrorWhenFocused → bool
-
If true, the error will also be displayed in the focused state. Otherwise the error is not displayed in the focused state.
finalinherited
- slideTransitionBeginOffset → Offset?
-
Begin Offset of ever
Pinputfield whenpinAnimationTypeis slidefinalinherited - smsRetriever → SmsRetriever?
-
By default Android autofill is Disabled, you can enable it by passing
smsRetrieverSmsRetriever exposes methods to listen for incoming SMS and extract code from it Recommended package to get sms code on Android is smart_auth https://pub.dev/packages/smart_authfinalinherited - submittedPinTheme → PinTheme?
-
Theme of the pin in submitted state
finalinherited
- textCapitalization → TextCapitalization
-
See EditableText.textCapitalization
finalinherited
- textInputAction → TextInputAction?
-
The type of action button to use for the keyboard.
finalinherited
- toolbarEnabled → bool
-
If true, paste button will appear on longPress event
finalinherited
- useNativeKeyboard → bool
-
Whether to use Native keyboard or custom one
when flag is set to false
Pinputwont be focusable anymore so you should set value ofPinput's TextEditingController programmaticallyfinalinherited -
validator
→ FormFieldValidator<
String> ? -
Return null if pin is valid or any String otherwise
finalinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< Pinput> -
Creates the mutable state for this widget at a given location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
locale(
BuildContext context) → String -
Available on Widget, provided by the WidgetExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited