PaymentFailed class
Host-facing widget: provides PaymentFailedBloc and PaymentFailedScene.
Set loadSavedCards to false for lightweight sheets (e.g. CVV re-entry)
where listing saved cards is unnecessary.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- PaymentFailed
- Available extensions
Constructors
-
PaymentFailed({Key? key, required OrderSheetCardInfo cardInfo, String errorCode = 'TXN_DECLINED', String? errorMessage, VoidCallback? onRetry, VoidCallback? onApplePay, VoidCallback? onGooglePay, VoidCallback? onSamsungPay, VoidCallback? onTabby, VoidCallback? onBack, bool askForCVV = false, void onCvvSubmitted(String cvv)?, required void onAddNewCard(CardData input), required PaymentRequest paymentRequest, bool loadSavedCards = true, SdkPaymentResult? paymentResult, void onUseOtherCard(CardData card)?, void onGooglePayResult(Map<
String, dynamic> result)?, void onPaymentError(Object? error)?}) -
const
Properties
- askForCVV → bool
-
final
- cardInfo → OrderSheetCardInfo
-
final
- errorCode → String
-
final
- errorMessage → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loadSavedCards → bool
-
final
- onAddNewCard → void Function(CardData input)
-
final
- onApplePay → VoidCallback?
-
final
- onBack → VoidCallback?
-
final
- onCvvSubmitted → void Function(String cvv)?
-
final
- onGooglePay → VoidCallback?
-
final
-
onGooglePayResult
→ void Function(Map<
String, dynamic> result)? -
final
- onPaymentError → void Function(Object? error)?
-
final
- onRetry → VoidCallback?
-
final
- onSamsungPay → VoidCallback?
-
final
- onTabby → VoidCallback?
-
final
- onUseOtherCard → void Function(CardData card)?
-
final
- paymentRequest → PaymentRequest
-
final
- paymentResult → SdkPaymentResult?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
locale(
BuildContext context) → String -
Available on Widget, provided by the WidgetExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited