utils/card_scheme library

Enums

CardScheme
Card scheme (network) detected from card number BIN.

Functions

cardSchemeAssetPath(CardScheme scheme) String?
Asset path (relative to package) for the card scheme logo. Returns null if the asset is not in the package; CardBrandImage will show a text placeholder.
cardSchemeDisplayName(CardScheme scheme) String
Display name for the card scheme.
cardSchemeFromBrandName(String brand) CardScheme
Resolves scheme from a brand string (e.g. from CardData.resolvedBrand).
cardSchemeFromNumber(String cardNumber) CardScheme
Detects card scheme from the first digits of cardNumber. cardNumber can contain spaces; only digits are used.